### R code from vignette source 'jaatha.Rnw'
### Encoding: ISO8859-1

###################################################
### code chunk number 1: foo
###################################################
options(keep.source = TRUE, width = 60)
jinfo <- packageDescription("jaatha")


###################################################
### code chunk number 2: install (eval = FALSE)
###################################################
## install.packages('jaatha')


###################################################
### code chunk number 3: Loading Jaatha
###################################################
library(jaatha)


###################################################
### code chunk number 4: Creating a demographic model in R
###################################################
dm <- dm.createDemographicModel(sample.sizes=c(12,14),
                                loci.num=50,
                                seq.length=1000)


###################################################
### code chunk number 5: Creating a demographic model in R
###################################################
dm <- dm.addSpeciationEvent(dm, .1, 5, new.time.point.name='tau')
dm <- dm.addSymmetricMigration(dm, .01, 5, new.par.name='M')
dm <- dm.addMutation(dm, 1, 20, new.par.name='theta')
dm <- dm.addRecombination(dm, fixed=20)


###################################################
### code chunk number 6: Load Fasta files
###################################################
library(ape)
# The path to the data
sample.file <- system.file('example_fasta_files/sample.fasta', 
                           package='jaatha')

# Reading the data
sample.data <- read.dna(sample.file, format='fasta', 
                        as.character=TRUE)

# Calculating the JSFS
sample.jsfs <- calculateJsfs(sample.data, 
                             pop1.rows=3:7, 
                             pop2.rows=8:12,
                             outgroup.row=1:2)
sample.jsfs


###################################################
### code chunk number 7: Summary Statistics
###################################################
# Real parameters: M = 1, tau = 1 and theta = 10
real.pars <- c(1,1,10) 

# Simulate a JSFS with this parameters
jsfs <- dm.simSumStats(dm, real.pars)

# Print the upper left part of the JSFS
jsfs[1:10, 1:10]


###################################################
### code chunk number 8: Initialize
###################################################
jaatha <- Jaatha.initialize(dm, jsfs=jsfs, seed=12345)


###################################################
### code chunk number 9: SaveJaatha
###################################################
if(!file.exists('cache/saved_objects')) dir.create('cache/saved_objects')
save(jaatha, file='cache/saved_objects/jaatha.Rsave')


###################################################
### code chunk number 10: LoadStartPoints
###################################################
load('cache/saved_objects/start-points.Rsave')


###################################################
### code chunk number 11: PrintStartPoints
###################################################
Jaatha.getStartingPoints(jaatha)


###################################################
### code chunk number 12: LoadFinalResults
###################################################
load('cache/saved_objects/jaatha-complete.Rsave')


###################################################
### code chunk number 13: printLT
###################################################
likelihoods <- Jaatha.getLikelihoods(jaatha)
print(likelihoods[1:3, ])


